package VMOMI::HostCertificateManagerCertificateInfoCertificateStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
